###~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~###
###~~~  Montereale Gavazzi et al. 2023:  Ecological analyses  ~~~###
###~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~###


library(dplyr)
library(tidyr)
library(lubridate)
library(openxlsx)
library(tables)
library(ggplot2)
library(devtools)
library(ggpmisc)
library(psych)
library(car)
library(mgcv)
library(stats)
library(ggpubr)
library(stats)
library(RColorBrewer)
library(nlme)
library(MASS)
library(glmmTMB)
library(pscl)
library(reshape)
library(tidyverse)
library(vegan)
library(cluster)
library(pracma)
library('maps')
library('maptools')
library('mapdata')
data("worldHiresMapEnv")

setwd("C:/Users/spaoletti/Documents/RBINS Scientific Collaborator Position/Paper Giacomo/Supplementary material")
palette1 <- c("#990000", "#CC6633",  "#FFCC99","#000066","#3366CC","#99CCFF")
palette2 <- c( "#CC6633",  "#FFCC99","#99CCFF","#3366CC")
palette3 <- c( "#3366CC", "#99CCFF","#CC6633")
palette4 <- c( "#CC66FF","#33CCCC")
palette5 <- c( "#33CCCC","#FFCC33", '#CC66FF')
palette6 <- c( "#FF6600","#66FF00")

### ~~~ TEMPORAL ANALYSIS: AREA NORD ~~~ #### 
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

### ~~~ Exploratory phase ~~~ #### 
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

dat <- read.xlsx("Montereale Gavazzi 2023_Area 1 benthic matrix.xlsx")
dat <- dat[c(1,3,11:18,20,22:23,26:32,35:40)]
#certain species i.e. mobile ones like fish are not considered here
#LMM can deal with non-highly different sample size, so no subselection needed
#However the samples in 2022 were taken every 5 seconds, I have reselected every 10 seconds to be consistent with method with other years
dat <- dat[dat$FreqImageSelection==10,]

dat$Year <- as.factor(dat$Year)
dat$count <- rep(1, 543)

# Creation response variables #### 
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

dat$TotAbu <- rowSums(dat[,c(5:20)])
dat$TotDens <- dat$TotAbu/dat$IMG_Area_m2

#Frames void of RRI LOW species
dat2 <- dat
dat2 <- dat2[dat2$RRI.LOW==0,]
table(dat2$RRI.LOW, dat2$Year) 
#relatively to sample size
tapply(dat$count, dat$Year, sum)
#6% in 2019, 7% in 2020, 23% in 2022

#Frames void of RRI MOD species
dat2 <- dat
dat2 <- dat2[dat2$RRI.MOD==0,]
table(dat2$RRI.MOD, dat2$Year) 
#relatively to sample size
tapply(dat$count, dat$Year, sum)
#15% in 2019, 17% in 2020, 25% in 2022

dat2 <- dat
dat2 <- dat2[dat2$TOT.annotations==0,]
table(dat2$TOT.annotations, dat2$Year) 


# Graphical visualization #### 
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

tiff('TEMP_LOWRRI_new.tiff', units="in", width=5, height=5, res=300, compression = 'lzw')
ggplot(data=dat, aes(x=Year, y=RRI.LOW)) + geom_boxplot(aes(x=Year, y=RRI.LOW, group=Year, fill=Year))   + labs(x="", y="Counts of low RRI species")  + theme_bw()+ theme(axis.text.x = element_text(size = rel(1.5)),axis.title.y = element_text(size = rel(1.5)),legend.text = element_text(size = rel(1.2)),legend.title = element_text(size = rel(1.5)))+ scale_fill_manual(values =palette5 )
dev.off()
tiff('TEMP_MODRRI_new.tiff', units="in", width=5, height=5, res=300, compression = 'lzw')
ggplot(data=dat, aes(x=Year, y=RRI.MOD)) + geom_boxplot(aes(x=Year, y=RRI.MOD, group=Year, fill=Year))   + labs(x="", y="Counts of moderate RRI species") + theme_bw() + theme(axis.text.x = element_text(size = rel(1.5)),axis.title.y = element_text(size = rel(1.5)),legend.text = element_text(size = rel(1.2)),legend.title = element_text(size = rel(1.5)))+ scale_fill_manual(values =palette5 )
dev.off()


### ~~~ Community analysis ~~~ #### 
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


# nMDS #### 
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

#prepare distance
clustersSpecies = as.matrix(dat[c(5:20)])
#rownames(clustersSpecies) = ID
clustersSpecies = clustersSpecies[ rowSums(clustersSpecies)!=0, ]
#issue with line 
# clustersSpecies = clustersSpecies[-256, ]

datY <-dat[c(1:20)]
datY = datY[ rowSums(datY[c(5:20)])!=0, ]
# datY = datY[-256,]


set.seed(45)
vare.mds <- metaMDS(clustersSpecies, distance="bray", k=3)  
plot(vare.mds, type = "text", cex = 0.5)

datScores1 <- scores(vare.mds, "sites", tidy = T)
datScores1$Year <- as.factor(datY$Year)
datScores2 <- scores(vare.mds, "species", tidy = T)

ggplot() + 
  geom_point(data=datScores1,aes(x=NMDS1,y=NMDS2,shape=Year,colour=Year),size=1) + # add the point markers
  geom_text(data=datScores2,aes(x=NMDS1,y=NMDS2,label=label), size=2) +  # add the species labels
  # geom_text(data=data.scores,aes(x=NMDS1,y=NMDS2,label=site),size=0,vjust=0) +  # add the site labels
  scale_color_manual(values=c("2019" = "#33CCCC", "2020" = "#FFCC33", "2022" = "#CC66FF")) +
  coord_equal() +
  theme_bw()


Year.a <- datScores1[datScores1$Year == "2019", ][chull(datScores1[datScores1$Year == "2019", c("NMDS1", "NMDS2")]), ]  # hull values for Year A
Year.b <- datScores1[datScores1$Year == "2020", ][chull(datScores1[datScores1$Year == "2020", c("NMDS1", "NMDS2")]), ]  # hull values for Year B
Year.c <- datScores1[datScores1$Year == "2022", ][chull(datScores1[datScores1$Year == "2022", c("NMDS1", "NMDS2")]), ]  # hull values for Year B
hull.data <- rbind(Year.a, Year.b, Year.c)  

tiff('TEMP_NMDS_new2.tiff', units="in", width=8, height=7, res=300, compression = 'lzw')

ggplot() + 
  geom_polygon(data=hull.data,aes(x=NMDS1,y=NMDS2,fill=Year,group=Year),alpha=0.30) + # add the convex hulls
  geom_point(data=datScores1,aes(x=NMDS1,y=NMDS2,shape=Year,fill=Year),colour="black", size=1.5) +
  scale_shape_manual(values = c(21,22,23))+
  geom_text(data=datScores2,aes(x=NMDS1,y=NMDS2,label=label),alpha=0.5, cex = 2.5) +  # add the species labels
 # add the point markers
  scale_colour_manual(values=c("2019" = "#33CCCC", "2020" = "#FFCC33", "2022" = "#CC66FF")) +
  scale_fill_manual(values=c("2019" = "#33CCCC", "2020" = "#FFCC33", "2022" = "#CC66FF")) +
  coord_equal() +
  xlim(-2,2)+
  theme_bw()+ theme(axis.text.x = element_text(size = rel(1.5)),axis.title.y = element_text(size = rel(1.5)),axis.title.x = element_text(size = rel(1.5)),legend.text = element_text(size = rel(1.2)),legend.title = element_text(size = rel(1.5)))
dev.off()

stressplot(vare.mds)

# ANOSIM #### 
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

d <- vegdist(clustersSpecies, method = "bray")

analysisofsimilarity = anosim(d, datY$Year)
summary(analysisofsimilarity)

#post-hoc pairwise anosim 2019 vs 2020
datYY <- datY[datY$Year!="2022",]
#prepare distance
clustersSpecies = as.matrix(datYY[c(5:20)])
clustersSpecies = clustersSpecies[ rowSums(clustersSpecies)!=0, ]

d <- vegdist(clustersSpecies, method = "bray")
analysisofsimilarity = anosim(d, datYY$Year)
summary(analysisofsimilarity)

#post-hoc pairwise anosim 2020 vs 2022
datYY <- datY[datY$Year!="2019",]
clustersSpecies = as.matrix(datYY[c(5:20)])
clustersSpecies = clustersSpecies[ rowSums(clustersSpecies)!=0, ]

d <- vegdist(clustersSpecies, method = "bray")
analysisofsimilarity = anosim(d, datYY$Year)
summary(analysisofsimilarity)

#post-hoc pairwise anosim 2019 vs 2022
datYY <- datY[datY$Year!="2020",]
clustersSpecies = as.matrix(datYY[c(5:20)])
clustersSpecies = clustersSpecies[ rowSums(clustersSpecies)!=0, ]

d <- vegdist(clustersSpecies, method = "bray")
analysisofsimilarity = anosim(d, datYY$Year)
summary(analysisofsimilarity)


# Indicator species analysis #### 
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Year = datY$Year

library(indicspecies)
inv = multipatt(clustersSpecies, Year, func = "r.g", control = how(nperm=9999))

summary(inv)



### ~~~ Statistical analysis ~~~ #### 
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

#Response var.: count data (abundance)
#Explanatory var.: year +
#Random effect: NONE because video ID is only 1 per year, there is no further nesting
#GLM/GAM for abundances (counts data)
#Assumptions: response var. normality and heterogeneity of variance 
#Checked at model validation stage by looking at residuals 

# Abundances #### 
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


#RRI LOW 
hist(dat$RRI.LOW)
qqPlot(dat$RRI.LOW)
shapiro.test(dat$RRI.LOW) 
leveneTest(RRI.LOW ~ Year, data = dat)

ModelAbundance2 <- zeroinfl(RRI.LOW ~ Year  | Year , dist = "negbin", link = "logit", data = dat)
summary(ModelAbundance2)
ModelAbundance3 <- hurdle(RRI.LOW ~ Year | Year , dist = "negbin", link = "logit", dat = dat)
summary(ModelAbundance3)

AIC(ModelAbundance, ModelAbundance2, ModelAbundance3) #hurdle model is best

plot(fitted(ModelAbundance3),residuals(ModelAbundance3)) #residuals vs fitted 
qqPlot(residuals(ModelAbundance3)) #residuals normality 
ggplot()+geom_point(aes(dat$Year,residuals(ModelAbundance3))) + geom_smooth(aes(dat$Year,residuals(ModelAbundance3)), method="loess")
#residuals vs covariates
#in this case matching fitted vs residuals having one only expl.var.
leveneTest(residuals(ModelAbundance3) ~ Year, data=dat) #residuals homogeneity of variance
#homogeneous 

#RRI MOD
hist(dat$RRI.MOD)
qqPlot(dat$RRI.MOD)
shapiro.test(dat$RRI.MOD) 
leveneTest(RRI.MOD ~ Year, data = dat)

ModelAbundance2 <- zeroinfl(RRI.MOD ~ Year  | Year , dist = "negbin", link = "logit", data = dat)
summary(ModelAbundance2)
ModelAbundance3 <- hurdle(RRI.MOD ~ Year | Year , dist = "negbin", link = "logit", dat = dat)
summary(ModelAbundance3)

AIC( ModelAbundance2, ModelAbundance3) #hurdle model is best

plot(fitted(ModelAbundance3),residuals(ModelAbundance3)) #residuals vs fitted 
qqPlot(residuals(ModelAbundance3)) #residuals normality 
ggplot()+geom_point(aes(dat$Year,residuals(ModelAbundance3))) + geom_smooth(aes(dat$Year,residuals(ModelAbundance3)), method="loess")
#residuals vs covariates
#in this case matching fitted vs residuals having one only expl.var.
leveneTest(residuals(ModelAbundance3) ~ Year, data=dat) #residuals homogeneity of variance
#homogeneous 




### ~~~ SPATIAL ANALYSIS: AREA SUD ~~~ #### 
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

### ~~~ Exploratory phase ~~~ #### 
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


dat <- read.xlsx("Montereale Gavazzi 2023_Area 2 benthic matrix.xlsx")
dat <- dat[c(1,2,3,11,12,17,18,20:24,27,30,32,34:41,44:46,49,53:58)]
#certain species i.e. mobile ones like fish are not considered here
dat$Spirobranchus.triqueter_pres<- ifelse(dat$Spirobranchus.triqueter_pres>1, 1, dat$Spirobranchus.triqueter_pres)

dat$Box_ID <- as.factor(dat$Box_ID)
dat$Video_ID <- as.factor(dat$Video_ID)
dat$count <- rep(1, 742)



# Creation response variables #### 
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

dat$TotAbu <- rowSums(dat[,c(7:27)])
dat$TotDens <- dat$TotAbu/dat$image_area_m2

#Frames void of RRI LOW species
dat2 <- dat
dat2 <- dat2[dat2$RRI.LOW==0,]
table(dat2$RRI.LOW, dat2$Exposure) 
#relatively to sample size
tapply(dat$count, dat$Exposure, sum)

#Frames void of RRI MOD species
dat2 <- dat
dat2 <- dat2[dat2$RRI.MOD==0,]
table(dat2$RRI.MOD, dat2$Exposure) 
#relatively to sample size
tapply(dat$count, dat$Exposure, sum)


# Graphical visualization #### 
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


tiff('SPAT_LOWRRI_180.tiff', units="in", width=5, height=5, res=300, compression = 'lzw')

ggplot(data=dat, aes(x=BoxID_ExSh, y=RRI.LOW)) + geom_boxplot(aes(x=Exposure, y=RRI.LOW,  fill=Exposure))   + labs(x="", y="Counts of low RRI species") + theme_bw()+ theme(axis.text.x = element_text(size = rel(1.5)),axis.title.y = element_text(size = rel(1.5)),legend.text = element_text(size = rel(1.2)),legend.title = element_text(size = rel(1.5)))+scale_fill_manual(values = c(palette6))

dev.off()

tiff('SPAT_MODRRI_180.tiff', units="in", width=5, height=5, res=300, compression = 'lzw')

ggplot(data=dat, aes(x=BoxID_ExSh, y=RRI.MOD)) + geom_boxplot(aes(x=Exposure, y=RRI.MOD,  fill=Exposure))   + labs(x="", y="Counts of moderate RRI species") + theme_bw() + theme(axis.text.x = element_text(size = rel(1.5)),axis.title.y = element_text(size = rel(1.5)),legend.text = element_text(size = rel(1.2)),legend.title = element_text(size = rel(1.5)))+scale_fill_manual(values = c(palette6))

dev.off()



ggplot(data=dat, aes(x=BoxID_ExSh, y=RRI.LOW)) + geom_boxplot(aes(x=BoxID_ExSh, y=RRI.LOW, group=Video_ID, fill=Exposure))   + labs(x="", y="Low RRI abundance") + theme_bw() + theme_bw()+scale_fill_manual(values = c(palette4))
ggplot(data=dat, aes(x=BoxID_ExSh, y=RRI.MOD)) + geom_boxplot(aes(x=BoxID_ExSh, y=RRI.MOD, group=Video_ID, fill=Exposure))   + labs(x="", y="Moderate RRI abundance") + theme_bw() + theme_bw()+scale_fill_manual(values = c(palette4))


### ~~~ Statistical analysis ~~~ #### 
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

#Response var.: Count data (abundance)
#Explanatory var.: factor 2 levels
#Random effect: NONE because video ID is only 1 per year, there is no further nesting
#GLM/GAM for abundances (counts data)
#Assumptions: response var. normality and heterogeneity of variance 
#Checked at model validation stage by looking at residuals 

# set.seed(1)

# dat4 <- subset(dat, dat$Video_ID == "04_2022")
# dat5 <- subset(dat, dat$Video_ID == "05_2022")
# dat6 <- subset(dat, dat$Video_ID == "06_2022")
# dat7 <- subset(dat, dat$Video_ID == "07_2022")
# dat8a <- subset(dat, dat$Video_ID == "08a_2022")
# dat8b <- subset(dat, dat$Video_ID == "08b_2022")
# 
# dat4 <- dat4[sample(nrow(dat4), 30), ]
# dat5 <- dat5[sample(nrow(dat5), 30), ]
# dat6 <- dat6[sample(nrow(dat6), 30), ]
# dat7 <- dat7[sample(nrow(dat7), 30), ]
# dat8a <- dat8a[sample(nrow(dat8a), 30), ]
# dat8b <- dat8b[sample(nrow(dat8b), 30), ]
# 
# dat=rbind(dat4,dat5, dat6,dat7,dat8a,dat8b)
 
# Abundances #### 
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

#RRI LOW 
hist(dat$RRI.LOW)
qqPlot(dat$RRI.LOW)
shapiro.test(dat$RRI.LOW) 
leveneTest(RRI.LOW ~ Exposure, data = dat)

ModelAbundance2 <- zeroinfl(RRI.LOW ~ Exposure  | Exposure , dist = "negbin", link = "logit", data = dat)
summary(ModelAbundance2)
ModelAbundance3 <- hurdle(RRI.LOW ~ Exposure | Exposure , dist = "negbin", link = "logit", dat = dat)
summary(ModelAbundance3)

AIC( ModelAbundance2, ModelAbundance3) #hurdle model is best

plot(fitted(ModelAbundance3),residuals(ModelAbundance3)) #residuals vs fitted 
qqPlot(residuals(ModelAbundance3)) #residuals normality 
ggplot()+geom_point(aes(dat$Exposure,residuals(ModelAbundance3))) + geom_smooth(aes(dat$Exposure,residuals(ModelAbundance3)), method="loess")
#residuals vs covariates:ok
#in this case matching fitted vs residuals having one only expl.var.
leveneTest(residuals(ModelAbundance1) ~ Exposure, data=dat) #residuals homogeneity of variance
#sensitive test- not highly not homogeneous 

#RRI MOD
hist(dat$RRI.MOD)
qqPlot(dat$RRI.MOD)
shapiro.test(dat$RRI.MOD) 
leveneTest(RRI.MOD ~ Exposure, data = dat)

ModelAbundance2 <- zeroinfl(RRI.MOD ~ Exposure  | Exposure , dist = "negbin", link = "logit", data = dat)
summary(ModelAbundance2)
ModelAbundance3 <- hurdle(RRI.MOD ~ Exposure | Exposure , dist = "negbin", link = "logit", dat = dat)
summary(ModelAbundance3)

AIC(ModelAbundance2, ModelAbundance3) #hurdle model is best

plot(fitted(ModelAbundance3),residuals(ModelAbundance3)) #residuals vs fitted 
qqPlot(residuals(ModelAbundance3)) #residuals normality 
ggplot()+geom_point(aes(dat$Exposure,residuals(ModelAbundance3))) + geom_smooth(aes(dat$Exposure,residuals(ModelAbundance3)), method="loess")
#residuals vs covariates
#in this case matching fitted vs residuals having one only expl.var.
leveneTest(residuals(ModelAbundance3) ~ Exposure, data=dat) #residuals homogeneity of variance
#homogeneous 


### ~~~ Community analysis ~~~ #### 
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


# nMDS #### 
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

#prepare distance
clustersSpecies = as.matrix(dat[c(7:27)])
clustersSpecies = clustersSpecies[ rowSums(clustersSpecies)!=0, ]


datY <-dat[c(1:27)]
datY = datY[ rowSums(datY[c(7:27)])!=0, ]


set.seed(46)
vare.mds <- metaMDS(clustersSpecies, distance="bray", k=3)  
plot(vare.mds, type = "text", cex = 0.5)

datScores1 <- scores(vare.mds, "sites", tidy = T)
datScores1$Exposure <- as.factor(datY$Exposure)
datScores2 <- scores(vare.mds, "species", tidy = T)

ggplot() + 
  geom_point(data=datScores1,aes(x=NMDS1,y=NMDS2,shape=Exposure,colour=Exposure),size=1) + # add the point markers
  geom_text(data=datScores2,aes(x=NMDS1,y=NMDS2,label=label), size=2) +  # add the species labels
  # geom_text(data=data.scores,aes(x=NMDS1,y=NMDS2,label=site),size=0,vjust=0) +  # add the site labels
  scale_color_manual(values=c("Exposed" = "#FF6600", "Sheltered" = "#66FF00")) +
  coord_equal() +
  theme_bw()

Exp.a <- datScores1[datScores1$Exposure == "Exposed", ][chull(datScores1[datScores1$Exposure == "Exposed", c("NMDS1", "NMDS2")]), ]  # hull values for Year A
Exp.b <- datScores1[datScores1$Exposure == "Sheltered", ][chull(datScores1[datScores1$Exposure == "Sheltered", c("NMDS1", "NMDS2")]), ]  # hull values for Year B
hull.data <- rbind(Exp.a, Exp.b)  

#tiff('SPAT_NMDS_totsamples.tiff', units="in", width=8, height=7, res=300, compression = 'lzw')
#tiff('SPAT_NMDS_180.tiff', units="in", width=8, height=7, res=300, compression = 'lzw')

ggplot() + 
  geom_polygon(data=hull.data,aes(x=NMDS1,y=NMDS2,fill=Exposure,group=Exposure),alpha=0.30) + # add the convex hulls
  geom_point(data=datScores1,aes(x=NMDS1,y=NMDS2,shape=Exposure,fill=Exposure),colour="black", size=1.5) +
  scale_shape_manual(values = c(21,22,23))+
  geom_text(data=datScores2,aes(x=NMDS1,y=NMDS2,label=label),alpha=0.5, cex = 2.5) +  # add the species labels
  # add the point markers
  scale_colour_manual(values=c("Exposed" = "#FF6600", "Sheltered" = "#66FF00")) +
  scale_fill_manual(values=c("Exposed" = "#FF6600", "Sheltered" = "#66FF00")) +
  coord_equal() +
  xlim(-2,2)+
  ylim(-2,1.5)+
  theme_bw() + 
  theme(axis.text.x = element_text(size = rel(1.5)),axis.title.y = element_text(size = rel(1.5)),axis.title.x = element_text(size = rel(1.5)),legend.text = element_text(size = rel(1.2)),legend.title = element_text(size = rel(1.5)))

#dev.off()

stressplot(vare.mds)

# ANOSIM #### 
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

#cretae distance matrix
d <- vegdist(clustersSpecies, method = "bray")

analysisofsimilarity = anosim(d, datY$Exposure)
summary(analysisofsimilarity)


# Indicator species analysis #### 
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
abund = datY[,1:27]

Exposure = datY$Exposure

library(indicspecies)
inv = multipatt(clustersSpecies, Exposure, func = "r.g", control = how(nperm=9999))

summary(inv)


